diff --git a/src/wp-content/themes/twentyseventeen/archive.php b/src/wp-content/themes/twentyseventeen/archive.php
index 8aa139f546..6623321353 100644
--- a/src/wp-content/themes/twentyseventeen/archive.php
+++ b/src/wp-content/themes/twentyseventeen/archive.php
@@ -37,7 +37,7 @@ get_header(); ?>
* If you want to override this in a child theme, then include a file
* called content-___.php (where ___ is the Post Format name) and that will be used instead.
*/
- get_template_part( 'components/post/content', get_post_format() );
+ get_template_part( 'template-parts/post/content', get_post_format() );
endwhile;
@@ -49,7 +49,7 @@ get_header(); ?>
else :
- get_template_part( 'components/post/content', 'none' );
+ get_template_part( 'template-parts/post/content', 'none' );
endif; ?>
diff --git a/src/wp-content/themes/twentyseventeen/footer.php b/src/wp-content/themes/twentyseventeen/footer.php
index e911c1a7da..2d72029b00 100644
--- a/src/wp-content/themes/twentyseventeen/footer.php
+++ b/src/wp-content/themes/twentyseventeen/footer.php
@@ -19,7 +19,7 @@
diff --git a/src/wp-content/themes/twentyseventeen/header.php b/src/wp-content/themes/twentyseventeen/header.php
index f76bbf379a..dc173d67e8 100644
--- a/src/wp-content/themes/twentyseventeen/header.php
+++ b/src/wp-content/themes/twentyseventeen/header.php
@@ -28,12 +28,12 @@
diff --git a/src/wp-content/themes/twentyseventeen/front-page.php b/src/wp-content/themes/twentyseventeen/front-page.php
index ea4ddc996d..555688857b 100644
--- a/src/wp-content/themes/twentyseventeen/front-page.php
+++ b/src/wp-content/themes/twentyseventeen/front-page.php
@@ -20,10 +20,10 @@ get_header(); ?>
$panels = array( '1', '2', '3', '4' );
$titles = array();
- global $twentyseventeencounter; // Used in components/page/content-front-page-panels.php file.
+ global $twentyseventeencounter; // Used in template-parts/page/content-front-page-panels.php file.
if ( 0 !== twentyseventeen_panel_count() || is_customize_preview() ) : // If we have pages to show.
@@ -44,7 +44,7 @@ get_header(); ?>
set_query_var( 'panel', $panel );
$titles[] = get_the_title(); // Put page titles in an array for use in navigation.
- get_template_part( 'components/page/content', 'front-page-panels' );
+ get_template_part( 'template-parts/page/content', 'front-page-panels' );
wp_reset_postdata();
else :